@@ -5,7 +5,7 @@ import weakref
 from importlib import import_module
 
 import sentry_sdk
-from sentry_sdk.consts import OP, SPANDATA
+from sentry_sdk.consts import OP, SPANDATA, SPANNAME
 from sentry_sdk.scope import add_global_event_processor, should_send_default_pii
 from sentry_sdk.serializer import add_global_repr_processor, add_repr_sequence_type
 from sentry_sdk.tracing import SOURCE_FOR_STYLE, TransactionSource
@@ -132,6 +132,7 @@ class DjangoIntegration(Integration):
         middleware_spans=True,  # type: bool
         signals_spans=True,  # type: bool
         cache_spans=False,  # type: bool
+        db_transaction_spans=False,  # type: bool
         signals_denylist=None,  # type: Optional[list[signals.Signal]]
         http_methods_to_capture=DEFAULT_HTTP_METHODS_TO_CAPTURE,  # type: tuple[str, ...]
     ):
@@ -148,6 +149,7 @@ class DjangoIntegration(Integration):
         self.signals_denylist = signals_denylist or []
 
         self.cache_spans = cache_spans
+        self.db_transaction_spans = db_transaction_spans
 
         self.http_methods_to_capture = tuple(map(str.upper, http_methods_to_capture))
 
@@ -633,6 +635,8 @@ def install_sql_hook():
         real_execute = CursorWrapper.execute
         real_executemany = CursorWrapper.executemany
         real_connect = BaseDatabaseWrapper.connect
+        real_commit = BaseDatabaseWrapper._commit
+        real_rollback = BaseDatabaseWrapper._rollback
     except AttributeError:
         # This won't work on Django versions < 1.6
         return
@@ -690,18 +694,53 @@ def install_sql_hook():
             _set_db_data(span, self)
             return real_connect(self)
 
+    def _commit(self):
+        # type: (BaseDatabaseWrapper) -> None
+        integration = sentry_sdk.get_client().get_integration(DjangoIntegration)
+
+        if integration is None or not integration.db_transaction_spans:
+            return real_commit(self)
+
+        with sentry_sdk.start_span(
+            op=OP.DB,
+            name=SPANNAME.DB_COMMIT,
+            origin=DjangoIntegration.origin_db,
+        ) as span:
+            _set_db_data(span, self, SPANNAME.DB_COMMIT)
+            return real_commit(self)
+
+    def _rollback(self):
+        # type: (BaseDatabaseWrapper) -> None
+        integration = sentry_sdk.get_client().get_integration(DjangoIntegration)
+
+        if integration is None or not integration.db_transaction_spans:
+            return real_rollback(self)
+
+        with sentry_sdk.start_span(
+            op=OP.DB,
+            name=SPANNAME.DB_ROLLBACK,
+            origin=DjangoIntegration.origin_db,
+        ) as span:
+            _set_db_data(span, self, SPANNAME.DB_ROLLBACK)
+            return real_rollback(self)
+
     CursorWrapper.execute = execute
     CursorWrapper.executemany = executemany
     BaseDatabaseWrapper.connect = connect
+    BaseDatabaseWrapper._commit = _commit
+    BaseDatabaseWrapper._rollback = _rollback
     ignore_logger("django.db.backends")
 
 
-def _set_db_data(span, cursor_or_db):
-    # type: (Span, Any) -> None
+def _set_db_data(span, cursor_or_db, db_operation=None):
+    # type: (Span, Any, Optional[str]) -> None
     db = cursor_or_db.db if hasattr(cursor_or_db, "db") else cursor_or_db
     vendor = db.vendor
     span.set_data(SPANDATA.DB_SYSTEM, vendor)
 
+    if db_operation is not None:
+        span.set_data(SPANDATA.DB_OPERATION, db_operation)
+
     # Some custom backends override `__getattr__`, making it look like `cursor_or_db`
     # actually has a `connection` and the `connection` has a `get_dsn_parameters`
     # attribute, only to throw an error once you actually want to call it.
