@@ -9,6 +9,7 @@ from ..utils import (
     _set_model_data,
     _should_send_prompts,
 )
+from .utils import _set_usage_data
 
 from typing import TYPE_CHECKING
 
@@ -103,10 +104,37 @@ def invoke_agent_span(user_prompt, agent, model, model_settings, is_streaming=Fa
     return span
 
 
-def update_invoke_agent_span(span, output):
+def update_invoke_agent_span(span, result):
     # type: (sentry_sdk.tracing.Span, Any) -> None
     """Update and close the invoke agent span."""
-    if span and _should_send_prompts() and output:
+    if not span or not result:
+        return
+
+    # Extract output from result
+    output = getattr(result, "output", None)
+
+    # Set response text if prompts are enabled
+    if _should_send_prompts() and output:
         set_data_normalized(
             span, SPANDATA.GEN_AI_RESPONSE_TEXT, str(output), unpack=False
         )
+
+    # Set token usage data if available
+    if hasattr(result, "usage") and callable(result.usage):
+        try:
+            usage = result.usage()
+            if usage:
+                _set_usage_data(span, usage)
+        except Exception:
+            # If usage() call fails, continue without setting usage data
+            pass
+
+    # Set model name from response if available
+    if hasattr(result, "response"):
+        try:
+            response = result.response
+            if hasattr(response, "model_name") and response.model_name:
+                span.set_data(SPANDATA.GEN_AI_RESPONSE_MODEL, response.model_name)
+        except Exception:
+            # If response access fails, continue without setting model name
+            pass
