@@ -276,7 +276,6 @@ class Span:
         "hub",
         "_context_manager_state",
         "_containing_transaction",
-        "_local_aggregator",
         "scope",
         "origin",
         "name",
@@ -345,7 +344,6 @@ class Span:
         self.timestamp = None  # type: Optional[datetime]
 
         self._span_recorder = None  # type: Optional[_SpanRecorder]
-        self._local_aggregator = None  # type: Optional[LocalAggregator]
 
         self.update_active_thread()
         self.set_profiler_id(get_profiler_id())
@@ -383,13 +381,6 @@ class Span:
         # type: (str) -> None
         self._span_id = value
 
-    def _get_local_aggregator(self):
-        # type: (...) -> LocalAggregator
-        rv = self._local_aggregator
-        if rv is None:
-            rv = self._local_aggregator = LocalAggregator()
-        return rv
-
     def __repr__(self):
         # type: () -> str
         return (
@@ -417,8 +408,7 @@ class Span:
     def __exit__(self, ty, value, tb):
         # type: (Optional[Any], Optional[Any], Optional[Any]) -> None
         if value is not None and should_be_treated_as_error(ty, value):
-            if self.status != SPANSTATUS.ERROR:
-                self.set_status(SPANSTATUS.INTERNAL_ERROR)
+            self.set_status(SPANSTATUS.INTERNAL_ERROR)
 
         with capture_internal_exceptions():
             scope, old_span = self._context_manager_state
@@ -488,6 +478,8 @@ class Span:
     ):
         # type: (...) -> Transaction
         """
+        DEPRECATED: Use :py:meth:`sentry_sdk.continue_trace`.
+
         Create a Transaction with the given params, then add in data pulled from
         the ``sentry-trace`` and ``baggage`` headers from the environ (if any)
         before returning the Transaction.
@@ -499,11 +491,6 @@ class Span:
 
         :param environ: The ASGI/WSGI environ to pull information from.
         """
-        if cls is Span:
-            logger.warning(
-                "Deprecated: use Transaction.continue_from_environ "
-                "instead of Span.continue_from_environ."
-            )
         return Transaction.continue_from_headers(EnvironHeaders(environ), **kwargs)
 
     @classmethod
@@ -516,6 +503,8 @@ class Span:
     ):
         # type: (...) -> Transaction
         """
+        DEPRECATED: Use :py:meth:`sentry_sdk.continue_trace`.
+
         Create a transaction with the given params (including any data pulled from
         the ``sentry-trace`` and ``baggage`` headers).
 
@@ -523,12 +512,7 @@ class Span:
         :param _sample_rand: If provided, we override the sample_rand value from the
             incoming headers with this value. (internal use only)
         """
-        # TODO move this to the Transaction class
-        if cls is Span:
-            logger.warning(
-                "Deprecated: use Transaction.continue_from_headers "
-                "instead of Span.continue_from_headers."
-            )
+        logger.warning("Deprecated: use sentry_sdk.continue_trace instead.")
 
         # TODO-neel move away from this kwargs stuff, it's confusing and opaque
         # make more explicit
@@ -582,16 +566,11 @@ class Span:
     ):
         # type: (...) -> Optional[Transaction]
         """
-        DEPRECATED: Use :py:meth:`sentry_sdk.tracing.Span.continue_from_headers`.
+        DEPRECATED: Use :py:meth:`sentry_sdk.continue_trace`.
 
         Create a ``Transaction`` with the given params, then add in data pulled from
         the given ``sentry-trace`` header value before returning the ``Transaction``.
         """
-        logger.warning(
-            "Deprecated: Use Transaction.continue_from_headers(headers, **kwargs) "
-            "instead of from_traceparent(traceparent, **kwargs)"
-        )
-
         if not traceparent:
             return None
 
@@ -676,7 +655,7 @@ class Span:
         # type: (int) -> None
         self.set_tag(
             "http.status_code", str(http_status)
-        )  # we keep this for backwards compatibility
+        )  # TODO-neel remove in major, we keep this for backwards compatibility
         self.set_data(SPANDATA.HTTP_STATUS_CODE, http_status)
         self.set_status(get_span_status_from_http_code(http_status))
 
@@ -739,13 +718,10 @@ class Span:
         }  # type: Dict[str, Any]
 
         if self.status:
+            rv["status"] = self.status
+            # TODO-neel remove redundant tag in major
             self._tags["status"] = self.status
 
-        if self._local_aggregator is not None:
-            metrics_summary = self._local_aggregator.to_json()
-            if metrics_summary:
-                rv["_metrics_summary"] = metrics_summary
-
         if len(self._measurements) > 0:
             rv["measurements"] = self._measurements
 
@@ -1122,13 +1098,6 @@ class Transaction(Span):
 
         event["measurements"] = self._measurements
 
-        # This is here since `to_json` is not invoked.  This really should
-        # be gone when we switch to onlyspans.
-        if self._local_aggregator is not None:
-            metrics_summary = self._local_aggregator.to_json()
-            if metrics_summary:
-                event["_metrics_summary"] = metrics_summary
-
         return scope.capture_event(event)
 
     def set_measurement(self, name, value, unit=""):
@@ -1505,8 +1474,3 @@ from sentry_sdk.tracing_utils import (
     has_tracing_enabled,
     maybe_create_breadcrumbs_from_span,
 )
-
-with warnings.catch_warnings():
-    # The code in this file which uses `LocalAggregator` is only called from the deprecated `metrics` module.
-    warnings.simplefilter("ignore", DeprecationWarning)
-    from sentry_sdk.metrics import LocalAggregator
